@@ -1,10 +1,19 @@
 package Apache::DumpHeaders;
+use strict;
 use Apache;
+use Apache::Constants qw(DECLINED OK);
+use vars qw($VERSION);
 
-$VERSION = 0.03;
+$VERSION = "0.20";
 
 sub handler {
-  my ($r) = @_;
+  my $r = shift;
+  if ($r->dir_config("DumpHeaders_Conditional")) {
+    return DECLINED unless $r->notes("DumpHeaders");
+  }
+  if ($r->dir_config("DumpHeaders_Percent")) {
+    return DECLINED unless rand(100) < $r->dir_config("DumpHeaders_Percent");
+  }
   if ($r->dir_config("DumpHeaders_IP")) {
     my $remote_ip = $r->connection->remote_ip;
     return DECLINED unless grep { /\Q$remote_ip\E/ }
@@ -34,18 +43,26 @@ Apache::DumpHeaders - Watch HTTP transaction via headers
  PerlLogHandler Apache::DumpHeaders
  PerlSetVar     DumpHeaders_File -
  PerlSetVar     DumpHeaders_IP "1.2.3.4 1.2.3.5"
+ #PerlSetVar     DumpHeaders_Conditional 
+ #PerlSetVar     DumpHeaders_Percent
 
 =head1 DESCRIPTION
 
 This module is used to watch an HTTP transaction, looking at client and
 servers headers.
 
-With Apache::ProxyPassThur configured, you are able to watch your browser
+With Apache::ProxyPassThru configured, you are able to watch your browser
 talk to any server besides the one with this module living inside.
 
 =head1 PARAMETERS
 
-This module is configured with PerlSetVar's.
+This module is configured with PerlSetVar's. All the "only dump if
+..." options are "AND" conditions. If not all of them matches we won't
+dump the headers. 
+
+If you need some more complicated logic you could use the
+DumpHeaders_Conditional parameter alone and have another module do the
+"dump or dump not" logic with r->notes("DumpHeaders").
 
 =head2 DumpHeaders_File
 
@@ -57,6 +74,16 @@ to.
 Optional parameter to specify which one or more IP addresses you want
 to dump traffic from.
 
+=head2 DumpHeaders_Conditional 
+
+If this is set to a true value we'll only dump the headers if another
+module have set r->notes("DumpHeaders") to a true value.
+
+=head2 DumpHeaders_Percent
+
+If this is set, we'll only dump the specified percent of the requests.
+
+
 =head1 SEE ALSO
 
 mod_perl(3), Apache(3), Apache::ProxyPassThru(3)
